<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reset Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'password' => '密码至少需要六个字符，并且要确认两者相符。',
    'reset' => '您的密码已重置。',
    'sent' => '已经寄送密码重置连结至您的电子邮件信箱。',
    'token' => '此密码重置权仗无效。',
    'user' => '找不到使用者的电子邮件地址。',

];
